summaryrefslogtreecommitdiffstats
path: root/src/BlockID.h
diff options
context:
space:
mode:
authormohe2015 <mohe2015@users.noreply.github.com>2016-11-06 19:30:19 +0100
committerMattes D <github@xoft.cz>2016-11-06 19:30:19 +0100
commit32b38fb2649fb282b6446c4e544866c0161aa7da (patch)
tree51d2fd4d507b9f46e80d90f357a6fee78d2f5ffa /src/BlockID.h
parentMerge pull request #3416 from cuberite/JsonSerializerErrorReport (diff)
downloadcuberite-32b38fb2649fb282b6446c4e544866c0161aa7da.tar
cuberite-32b38fb2649fb282b6446c4e544866c0161aa7da.tar.gz
cuberite-32b38fb2649fb282b6446c4e544866c0161aa7da.tar.bz2
cuberite-32b38fb2649fb282b6446c4e544866c0161aa7da.tar.lz
cuberite-32b38fb2649fb282b6446c4e544866c0161aa7da.tar.xz
cuberite-32b38fb2649fb282b6446c4e544866c0161aa7da.tar.zst
cuberite-32b38fb2649fb282b6446c4e544866c0161aa7da.zip
Diffstat (limited to 'src/BlockID.h')
-rw-r--r--src/BlockID.h30
1 files changed, 26 insertions, 4 deletions
diff --git a/src/BlockID.h b/src/BlockID.h
index 5af0cc4f5..bf668377c 100644
--- a/src/BlockID.h
+++ b/src/BlockID.h
@@ -215,10 +215,32 @@ enum BLOCKTYPE
E_BLOCK_JUNGLE_DOOR = 195,
E_BLOCK_ACACIA_DOOR = 196,
E_BLOCK_DARK_OAK_DOOR = 197,
-
- // Keep these two as the last values. Update the last block value when adding another block
- // IsValidBlock() depends on this
- E_BLOCK_NUMBER_OF_TYPES = E_BLOCK_DARK_OAK_DOOR + 1, ///< Number of individual (different) blocktypes
+ E_BLOCK_END_ROD = 198,
+ E_BLOCK_CHORUS_PLANT = 199,
+ E_BLOCK_CHORUS_FLOWER = 200,
+ E_BLOCK_PURPUR_BLOCK = 201,
+ E_BLOCK_PURPUR_PILLAR = 202,
+ E_BLOCK_PURPUR_STAIRS = 203,
+ E_BLOCK_PURPUR_DOUBLE_SLAB = 204,
+ E_BLOCK_PURPUR_SLAB = 205,
+ E_BLOCK_END_BRICKS = 206,
+ E_BLOCK_BEETROOTS = 207,
+ E_BLOCK_GRASS_PATH = 208,
+ E_BLOCK_END_GATEWAY = 209,
+ E_BLOCK_REPEATING_COMMAND_BLOCK = 210,
+ E_BLOCK_CHAIN_COMMAND_BLOCK = 211,
+ E_BLOCK_FROSTED_ICE = 212,
+ E_BLOCK_MAGMA = 213,
+ E_BLOCK_NETHER_WART_BLOCK = 214,
+ E_BLOCK_RED_NETHER_BRICK = 215,
+ E_BLOCK_BONE_BLOCK = 216,
+ E_BLOCK_STRUCTURE_VOID = 217,
+ // ...
+ E_BLOCK_STRUCTURE_BLOCK = 255,
+
+ // Keep these two as the last values. Update the last block value to the last block with an id less than 255 when adding another block
+ // IsValidBlock() depends on this (255 gets checked additionally because there is a gap. See http://minecraft.gamepedia.com/Data_values#Block_IDs
+ E_BLOCK_NUMBER_OF_TYPES = E_BLOCK_STRUCTURE_VOID + 1, ///< Number of individual (different) blocktypes
E_BLOCK_MAX_TYPE_ID = E_BLOCK_NUMBER_OF_TYPES - 1, ///< Maximum BlockType number used
// Synonym or ID compatibility